(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
	typeof define === 'function' && define.amd ? define(['exports'], factory) :
	(global = global || self, factory(global['vue-image-lazyload'] = {}));
}(this, (function (exports) { 'use strict';

	var LazyLoad = {
	  inserted: function inserted(el) {
	    var imageElement = Array.from(el.children).find(function (el) {
	      return el.nodeName === 'IMG';
	    });
	    var sourceElement = Array.from(el.children).find(function (el) {
	      return el.nodeName === 'SOURCE';
	    });

	    function loadImage() {
	      if (imageElement) {
	        imageElement.addEventListener('load', function () {
	          setTimeout(function () {
	            return el.classList.add('loaded');
	          }, 100);
	        });
	        imageElement.src = imageElement.dataset.src;
	      }

	      if (sourceElement) {
	        sourceElement.srcset = sourceElement.dataset.srcset;
	      }
	    }

	    function handleIntersect(entries, observer) {
	      entries.forEach(function (entry) {
	        if (entry.isIntersecting) {
	          loadImage();
	          observer.unobserve(el);
	        }
	      });
	    }

	    function createObserver() {
	      var options = {
	        root: null,
	        threshold: 0
	      };
	      var observer = new IntersectionObserver(handleIntersect, options);
	      observer.observe(el);
	    }

	    function handleMutation(mutations) {
	      mutations.forEach(function (mutation) {
	        if (mutation.attributeName === 'data-src' || mutation.attributeName === 'data-srcset') {
	          loadImage();
	        }
	      });
	    }

	    function createMutationsObserver() {
	      var options = {
	        subtree: true,
	        attributes: true,
	        attributeFilter: ['data-src', 'data-srcset']
	      };
	      var observer = new MutationObserver(handleMutation);
	      observer.observe(el, options);
	    }

	    if (window['MutationObserver']) {
	      createMutationsObserver();
	    }

	    if (window['IntersectionObserver']) {
	      createObserver();
	    } else {
	      loadImage();
	    }
	  }
	};

	function install(Vue) {
	  Vue.directive('lazy-load', LazyLoad);
	}
	var plugin = {
	  install: install
	};
	var GlobalVue = null;

	if (typeof window !== 'undefined') {
	  GlobalVue = window.Vue;
	} else if (typeof global !== 'undefined') {
	  GlobalVue = global.Vue;
	}

	if (GlobalVue) {
	  GlobalVue.use(plugin);
	}

	exports.LazyLoad = LazyLoad;
	exports.default = plugin;
	exports.install = install;

	Object.defineProperty(exports, '__esModule', { value: true });

})));
